@@ -163,7 +163,7 @@
             configTemplate: AJS.gadgets.templater.Form ({
 
                 // target of html injection
-                target: AJS.$("<div id='config' />").appendTo(document.body),
+                target: AJS.$("<div id='config' />").insertAfter(gadget.getView()),
 
                 // proxy to user defined descriptor to ensure descriptor has gadget context
                 // we can also append additional configuration options, not set by user, to config form.
@@ -297,8 +297,12 @@
         gadget.showConfig = function () {
 
             var restoreValuesFromHash = function () {
-                if (!/#rpctoken=[0-9]+$/.test(window.location.href)) {
-                    var options, fields = window.location.href.replace(/.*?#/,"").split("&");
+                
+                var options, fields;
+
+                /* If preselected form fields have been serialized to the end of the hash */
+                if (/#rpctoken/.test(window.location.href) && !/#rpctoken=[0-9]+$/.test(window.location.href)) {
+                    fields = window.location.href.replace(/.*?#/,"").split("&");
                     AJS.$.each(fields, function () {
                         var name = this.split("=")[0], val = this.split("=")[1], field = AJS.$(":input[name=" + name + "]");
                         if (field.length > 0) {
@@ -319,6 +323,14 @@
             };
 
             gadget.configTemplate.addCallback(function(){
+
+                /* Having issues with ie calculating correct height, so doing it the manual way */
+                function getResizeHeight () {
+                    var configHeight = gadget.getConfig().outerHeight(),
+                        footerHeight = jQuery(".footer", gadget.getGadget()).length === 1 ? gadget.getFooter().outerHeight() : 0;
+                    return configHeight + footerHeight;
+                }
+
                 AJS.$("body").addClass("config-active");
                 gadget.configTemplate.getTarget().show();
                 // Restores the values of a partly completed form. This happens in the case of an oauth approval, the
@@ -328,7 +340,7 @@
                     gadget.appendFooterApproval(gadget.approvalRequest);
                 }
                 AJS.$("button", ".footer").hide();
-                gadget.resize();
+                gadget.resize(getResizeHeight());
             });
             return function () {
                 gadget.configTemplate.build();
@@ -343,23 +355,27 @@
          * @override
          */
         gadget.showView = function (refresh, resize) {
+
+            gadget.addMenuItem("configure", gadget.getMsg("gadget.common.configure"), function (e) {
+                gadget.showConfig();
+                e.preventDefault();
+            });
+
+            if (gadget.addReloadButton) {
+                gadget.addReloadButton();
+            }
+
             if (refresh) {
                 gadget.viewTemplate.build();
             } else {
                 AJS.$("body").removeClass("config-active");
                 gadget.configTemplate.getTarget().hide();
+
                 if (resize !== false) {
-                    gadget.resize();
+                    gadget.resize(gadget.getViewResizeHeight());
                 }
                 AJS.$("button", ".footer").show();
             }
-            gadget.addMenuItem("configure", gadget.getMsg("gadget.common.configure"), function (e) {
-                gadget.showConfig();
-                e.preventDefault();
-            });
-            if (gadget.addReloadButton) {
-                gadget.addReloadButton();
-            }
         };
 
         /**
